==> Morpho-0.2.B2.tar.gz: Morpho-0.2.B2/src/jp/morpho/webapp/servlet/jsp/tagext/html/Attrs.java <==
/*
 * Copyright (c) 2003, Morpho Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the Morpho Project nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.morpho.webapp.servlet.jsp.tagext.html;

/**
 * <P>
 * Generic Attributes  attrs ɽޤ
 * </P>
 * <P>
 * attrs  HTML 4 ϼΤȤǤ
 * <PRE>
 * &lt;!ENTITY % coreattrs
 *  "id          ID             #IMPLIED  -- document-wide unique id --
 *   class       CDATA          #IMPLIED  -- space-separated list of classes --
 *   style       %StyleSheet;   #IMPLIED  -- associated style info --
 *   title       %Text;         #IMPLIED  -- advisory title --"
 *   &gt;
 * 
 * &lt;!ENTITY % i18n
 *  "lang        %LanguageCode; #IMPLIED  -- language code --
 *   dir         (ltr|rtl)      #IMPLIED  -- direction for weak/neutral text --"
 *   &gt;
 * 
 * &lt;!ENTITY % events
 *  "onclick     %Script;       #IMPLIED  -- a pointer button was clicked --
 *   ondblclick  %Script;       #IMPLIED  -- a pointer button was double clicked--
 *   onmousedown %Script;       #IMPLIED  -- a pointer button was pressed down --
 *   onmouseup   %Script;       #IMPLIED  -- a pointer button was released --
 *   onmouseover %Script;       #IMPLIED  -- a pointer was moved onto --
 *   onmousemove %Script;       #IMPLIED  -- a pointer was moved within --
 *   onmouseout  %Script;       #IMPLIED  -- a pointer was moved away --
 *   onkeypress  %Script;       #IMPLIED  -- a key was pressed and released --
 *   onkeydown   %Script;       #IMPLIED  -- a key was pressed down --
 *   onkeyup     %Script;       #IMPLIED  -- a key was released --"
 *   &gt;
 * 
 * &lt;!-- Reserved Feature Switch --&gt;
 * &lt;!ENTITY % HTML.Reserved "IGNORE"&gt;
 * 
 * &lt;!-- The following attributes are reserved for possible future use --&gt;
 * &lt;![ %HTML.Reserved; [
 * &lt;!ENTITY % reserved
 *  "datasrc     %URI;          #IMPLIED  -- a single or tabular Data Source --
 *   datafld     CDATA          #IMPLIED  -- the property or column name --
 *   dataformatas (plaintext|html) plaintext -- text or html --"
 *   &gt;
 * ]]&gt;
 * 
 * &lt;!ENTITY % reserved ""&gt;
 * 
 * &lt;!ENTITY % attrs "%coreattrs; %i18n; %events;"&gt;
 * </PRE>
 * </P>
 * @author Kumiko Hiroi
 */
public interface Attrs extends CoreAttrs, Events, I18n
{

}

==> Morpho-1.0.B2.tar.gz: Morpho-1.0.B2/src/jp/morpho/webapp/servlet/jsp/tagext/html/Attrs.java <==
/*
 * Copyright (c) 2003, Morpho Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the Morpho Project nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.morpho.webapp.servlet.jsp.tagext.html;

/**
 * <P>
 * Generic Attributes  attrs \܂B
 * </P>
 * <P>
 * attrs  HTML 4 `͎̂ƂłB
 * <PRE>
 * &lt;!ENTITY % coreattrs
 *  "id          ID             #IMPLIED  -- document-wide unique id --
 *   class       CDATA          #IMPLIED  -- space-separated list of classes --
 *   style       %StyleSheet;   #IMPLIED  -- associated style info --
 *   title       %Text;         #IMPLIED  -- advisory title --"
 *   &gt;
 * 
 * &lt;!ENTITY % i18n
 *  "lang        %LanguageCode; #IMPLIED  -- language code --
 *   dir         (ltr|rtl)      #IMPLIED  -- direction for weak/neutral text --"
 *   &gt;
 * 
 * &lt;!ENTITY % events
 *  "onclick     %Script;       #IMPLIED  -- a pointer button was clicked --
 *   ondblclick  %Script;       #IMPLIED  -- a pointer button was double clicked--
 *   onmousedown %Script;       #IMPLIED  -- a pointer button was pressed down --
 *   onmouseup   %Script;       #IMPLIED  -- a pointer button was released --
 *   onmouseover %Script;       #IMPLIED  -- a pointer was moved onto --
 *   onmousemove %Script;       #IMPLIED  -- a pointer was moved within --
 *   onmouseout  %Script;       #IMPLIED  -- a pointer was moved away --
 *   onkeypress  %Script;       #IMPLIED  -- a key was pressed and released --
 *   onkeydown   %Script;       #IMPLIED  -- a key was pressed down --
 *   onkeyup     %Script;       #IMPLIED  -- a key was released --"
 *   &gt;
 * 
 * &lt;!-- Reserved Feature Switch --&gt;
 * &lt;!ENTITY % HTML.Reserved "IGNORE"&gt;
 * 
 * &lt;!-- The following attributes are reserved for possible future use --&gt;
 * &lt;![ %HTML.Reserved; [
 * &lt;!ENTITY % reserved
 *  "datasrc     %URI;          #IMPLIED  -- a single or tabular Data Source --
 *   datafld     CDATA          #IMPLIED  -- the property or column name --
 *   dataformatas (plaintext|html) plaintext -- text or html --"
 *   &gt;
 * ]]&gt;
 * 
 * &lt;!ENTITY % reserved ""&gt;
 * 
 * &lt;!ENTITY % attrs "%coreattrs; %i18n; %events;"&gt;
 * </PRE>
 * </P>
 * @author Kumiko Hiroi
 */
public interface Attrs extends CoreAttrs, Events, I18n
{

}
